# Notes for developers and translators

## Scripting notes

All scripts are written for the POSIX shell (`/bin/sh`), with no extensions,
for maximum portability.  The "`shellcheck`" utility should be used on each
component to highlight any inconsistencies.

The main entry point is "`src/cli.sh`".  The script that is installed by
"`make install`" is a concatenation of "`settings.sh`" (derived from
"`settings.sh.in`" by the "`configure`" script) and "`src/cli.sh`".

Each component should not output any progress or error information directly,
unless it comes straight from the underlying utility it's acting as a
wrapper for.  Instead, call the "`actInfo`" function for informational
messages, "`actDebug`" for debugging messages, and "`actError`" to report an
error; those functions take care of checking the command-line arguments and
adding the appropriate prefixes.  See "`src/output.sh`" for these functions,
and note that "`actError`" expects a standardised argument, not an arbitrary
string - this is so that human-readable error messages are all defined in
one place and can be translated more easily in future.

Components should not use hard-coded paths; refer to variables defined in
"`settings.sh`" instead.

Whenever a command needs to be run to gather information or perform an
action, prefix it with "`actRun`" so that the appropriate informational
messages are generated automatically.  Don't use "`actRun`" in the middle of
pipelines that are processing the output of something else - for example
it's not generally needed before "`awk`" or "`sed`".

Functions to perform the actions for particular system types are defined via
overrides.  For example, for all of the actions starting with "`package-`",
the "`actPackage`" function in "`src/package.sh`" is called first, which
then determines which package manager is in use; that gives the prefix for
the next parts, so for the Debian package manager, "`src/debian-package.sh`"
is loaded, which defines functions such as "`actDebianPackageInstall`" for
the "`package-install`" action.  See "`src/override.sh`" for details.


## Translation notes

There are no notes for translators yet, as internationalisation attempts
have not yet begun.  Please contact the author if you wish to assist.


## Release checklist

The package maintainer should run through these steps for a new release:

 * Version bump and documentation checks:
   * Update the version in `configure.ac` and `docs/NEWS.md`
   * Check that `docs/NEWS.md` is up to date
   * Check that `docs/TODO.md` is up to date
   * Check that the manual `docs/act.8` is up to date
   * Check that the copyright years in `src/version.sh` are up to date
   * Run "`make docs/act.8.md`" and, if using VPATH, copy the result to the source directory
 * Ensure everything has been committed to the repository
 * Run "`autoreconf`" in the source directory
 * Consistency and build checks:
   * Wipe the build directory, and run "`configure`" there
   * Run "`make distcheck`"
   * Run "`./configure && make check`", using the `tar.gz` that was just created
 * Run "`make release MAINTAINER=<signing-user>`"
 * Update the project web site:
   * Copy the release `.tar.gz`, `.txt`, and `.asc` files to the web site
   * Run "`make docs/act.8.html docs/NEWS.html`" and copy the results to the web site
   * Update the version numbers on the web site
   * Update the package index on the web site
 * Create a new release in the repository, and apply the associated tag

