#!/bin/sh
#
# Functions for running hooks.
#
# Copyright 2023-2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

# Run the hooks for either pre or post ($1) action or class $2, in
# alphanumeric order.  Any which have already been run will be skipped; any
# that are run, have their paths added to the ACT_HOOKS_LOADED exported
# environment variable beforehand, so that if those hooks run this utility,
# the second invocation won't load the same hook again.
#
actHooks () {
	test -n "$1" || return
	test -n "$2" || return
	test -d "${ACTIONHOOKDIR}/$1/$2" || return
	shift 2
	eligibleHookScripts="$(find "${ACTIONHOOKDIR}/$1/$2" -type f -name "*.sh" -maxdepth 1 2>/dev/null | sort)"
	alreadyLoadedHookScripts="${ACT_HOOKS_LOADED}"
	ACT_HOOKS_LOADED="$(printf "%s\n%s\n" "${alreadyLoadedHookScripts}" "${eligibleHookScripts}")"
	export ACT_HOOKS_LOADED
	printf "%s\n" "${eligibleHookScripts}" | \
	{
		while read -r hookScript; do
			if printf "%s\n" "${alreadyLoadedHookScripts}" | grep -Fxq "${hookScript}"; then
				actDebug "skipping hook script used in prior invocation: ${hookScript}"
			else
				actDebug "running hook script: ${hookScript}"
				# Note that we can't portably pass arguments to ".".
				. "${hookScript}"
			fi
		done
	}
}
