#!/bin/sh
#
# Functions relating to output.
#
# Copyright 2023-2024 Andrew Wood
#
# License GPLv3+: GNU GPL version 3 or later; see `docs/COPYING'.
#

# Output a standardised error message $1 with optional parameter $2.
#
actError () {
	{
	case "$1" in
	"NO-ACTION")
		printf "act: %s\n" "no action specified"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNKNOWN-OPTION")
		printf "act: %s -- '%s'\n" "unknown option" "$2"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNKNOWN-ACTION")
		printf "act: %s -- '%s'\n" "unknown action" "$2"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"UNSUPPORTED-ACTION")
		printf "act: %s -- '%s'\n" "unsupported action on this system" "$2"
		printf "%s\n" "Try \`act --help' for more information."
		;;
	"MISSING-ARGUMENT")
		printf "act: %s: %s\n" "$2" "missing argument for action"
		;;
	"UNEXPECTED-ARGUMENT")
		printf "act: %s: %s\n" "$2" "action requires no argument"
		;;
	"NO-PACKAGE-MANAGER")
		printf "act: %s\n" "no supported package manager found"
		;;
	"NO-SERVICE-MANAGER")
		printf "act: %s\n" "no supported service manager found"
		;;
	*)
		printf "act: %s\n" "$1"
		;;
	esac
	} 1>&2
}


# Output an informational message $1, to standard error, if verbose mode is
# enabled.
#
actInfo () {
	test -n "${optionVerbose}" || return
	test "${optionVerbose}" -gt 0 || return
	printf "act: info: %s\n" "$1" 1>&2
}


# Output a debugging message $1, to standard error, if extra-verbose mode is
# enabled.
#
actDebug () {
	test -n "${optionVerbose}" || return
	test "${optionVerbose}" -gt 1 || return
	printf "act: debug: %s\n" "$1" 1>&2
}

# Preserve stderr as fd 3 so that actRun foo 2>/dev/null can still write
# info to the original stderr.
exec 3>&2

# Run a command; in verbose mode, report what is being run.
#
actRun () {
	actInfo "running: $*" 2>&3
	"$@"
	return $?
}
